@@ -66,17 +66,24 @@ def deep_equal(seq1: Iterable[Any],
 
             if (value1 is None) ^ (value2 is None):
                 return False
+            elif isinstance(value1, (XPathArray, XPathMap, XPathNode)) ^ \
+                    isinstance(value2, (XPathArray, XPathMap, XPathNode)):
+                return False
             elif value1 is None:
                 return True
-            elif isinstance(value1, XPathNode) ^ isinstance(value2, XPathNode):
-                return False
+            elif isinstance(value1, XPathMap):
+                assert isinstance(value2, XPathMap)
+                return value1 == value2
+            elif isinstance(value1, XPathArray):
+                assert isinstance(value2, XPathArray)
+                return value1 == value2
             elif isinstance(value1, XPathNode):
                 assert isinstance(value2, XPathNode)
                 if value1.__class__ != value2.__class__:
                     return False
                 elif isinstance(value1, etree_node_types):
                     assert isinstance(value2, etree_node_types)
-                    if not etree_deep_equal(value1.obj, value2.obj):
+                    if not etree_deep_equal(value1.value, value2.value):
                         return False
                 elif isinstance(value1, EtreeDocumentNode):
                     assert isinstance(value2, EtreeDocumentNode)
@@ -87,14 +94,14 @@ def deep_equal(seq1: Iterable[Any],
                             return False
                         elif isinstance(child1, etree_node_types):
                             assert isinstance(child2, etree_node_types)
-                            if not etree_deep_equal(child1.obj, child2.obj):
+                            if not etree_deep_equal(child1.value, child2.value):
                                 return False
                         elif isinstance(child1, TextNode):
                             assert isinstance(child2, TextNode)
-                            if cm.ne(child1.obj, child2.obj):
+                            if cm.ne(child1.value, child2.value):
                                 return False
 
-                elif cm.ne(value1.obj, value2.obj):
+                elif cm.ne(value1.value, value2.value):
                     return False
                 elif isinstance(value1, TextAttributeNode):
                     if cm.ne(value1.name, value2.name):
@@ -187,9 +194,10 @@ def deep_compare(obj1: Any,
 
     def etree_deep_compare(e1: ElementProtocol, e2: ElementProtocol) -> int:
         nonlocal result
-        result = cm.strcoll(e1.tag, e2.tag)
-        if result:
-            return result
+        if not callable(e1.tag) and not callable(e2.tag):
+            result = cm.strcoll(e1.tag, e2.tag)
+            if result:
+                return result
 
         result = cm.strcoll((e1.text or '').strip(), (e2.text or '').strip())
         if result:
@@ -249,7 +257,7 @@ def deep_compare(obj1: Any,
                     raise xpath_error('XPTY0004', msg, token=token)
                 elif isinstance(value1, etree_node_types):
                     assert isinstance(value2, etree_node_types)
-                    result = etree_deep_compare(value1.obj, value2.obj)
+                    result = etree_deep_compare(value1.value, value2.value)
                     if result:
                         return result
                 elif isinstance(value1, EtreeDocumentNode):
@@ -264,19 +272,19 @@ def deep_compare(obj1: Any,
                             raise xpath_error('XPTY0004', msg, token=token)
                         elif isinstance(child1, etree_node_types):
                             assert isinstance(child2, etree_node_types)
-                            result = etree_deep_compare(child1.obj, child2.obj)
+                            result = etree_deep_compare(child1.value, child2.value)
                             if result:
                                 return result
                         elif isinstance(child1, TextNode):
                             assert isinstance(child2, TextNode)
                             result = cm.strcoll(
-                                child1.obj.strip(), child2.obj.strip()
+                                child1.value.strip(), child2.value.strip()
                             )
                             if result:
                                 return result
                 elif isinstance(value1, TextNode):
                     assert isinstance(value2, TextNode)
-                    result = cm.strcoll(value1.obj, value2.obj)
+                    result = cm.strcoll(value1.value, value2.value)
                     if result:
                         return result
                 elif isinstance(value1, TextAttributeNode):
@@ -315,7 +323,8 @@ def deep_compare(obj1: Any,
 
                     elif isinstance(value1, float):
                         if math.isnan(value1):
-                            if not math.isnan(value2):
+                            if not isinstance(value2, (float, Decimal)) \
+                                    or not math.isnan(value2):
                                 return -1
                         elif math.isinf(value1):
                             if value1 != value2:
